#[non_exhaustive]pub enum ResourceDim {
GpuSeconds,
GridCarbonGramsCo2,
PeerVerifierMillis,
CorpusBitsAdded,
KnowledgeSpillover,
FxVolatilityDelta,
AuctionDelay,
}Expand description
One axis of externality the auction internalizes. Each variant captures a measurable externality and an oracle that signs claims about it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GpuSeconds
GPU compute time consumed, in micro-seconds.
GridCarbonGramsCo2
Grid carbon intensity × electrical energy, in micro-grams CO₂-eq.
PeerVerifierMillis
Peer-verifier CPU / I/O time imposed on the witness federation when this call’s lineage edges get verified, in milliseconds.
CorpusBitsAdded
Bits added to the corpus when this call’s artifact is recorded.
KnowledgeSpillover
Negative externality (= positive spillover): knowledge produced and made available to other agents.
FxVolatilityDelta
FX volatility imposed on subsequent FX-denominated bids.
AuctionDelay
Auction-clearing delay imposed on downstream auctions, in milliseconds.